pub enum AccountStatus {
Unmodified,
Modified,
Destroyed,
DestroyedModified,
}Variants
Unmodified
Account was only read and not mutated at all.
Modified
Account accessed mutably, doesn’t necessarily mean that its state has changed though but it could
Destroyed
Contract executed a SELFDESTRUCT
DestroyedModified
Contract has been destroyed and then modified This is a particular state because we’ll still have in the Database the storage (trie) values but they are actually invalid.