Module call_frame

Module call_frame 

Structs

CallFrame
A call frame, or execution environment, is the context in which the EVM is currently executing. One context can trigger another with opcodes like CALL or CREATE. Call frames relationships can be thought of as a parent-child relation.
CallFrameBackup
Stack
The EVM uses a stack-based architecture and does not use registers like some other VMs.