pub struct AccountUpdate {
pub address: H160,
pub removed: bool,
pub info: Option<AccountInfo>,
pub code: Option<Code>,
pub added_storage: HashMap<H256, U256, FxBuildHasher>,
pub removed_storage: bool,
}Fields
address: H160removed: boolinfo: Option<AccountInfo>code: Option<Code>added_storage: HashMap<H256, U256, FxBuildHasher>removed_storage: boolIf account was destroyed and then modified we need this for removing its storage but not the entire account.
Implementations
Sourceimpl AccountUpdate
impl AccountUpdate
Sourcepub fn new(address: H160) -> AccountUpdate
pub fn new(address: H160) -> AccountUpdate
Creates new empty update for the given account
Sourcepub fn removed(address: H160) -> AccountUpdate
pub fn removed(address: H160) -> AccountUpdate
Creates new update representing an account removal
pub fn merge(&mut self, other: AccountUpdate)