EVMConfig

Struct EVMConfig 

pub struct EVMConfig {
    pub fork: Fork,
    pub blob_schedule: ForkBlobSchedule,
}
This struct holds special configuration variables specific to the EVM. In most cases, at least at the time of writing (February 2025), you want to use the default blob_schedule values for the specified Fork. The “intended” way to do this is by using the EVMConfig::canonical_values(fork: Fork) function.

However, that function should NOT be used IF you want to use a custom ForkBlobSchedule, like it’s described in EIP-7840 Values are determined by EIP-7691

Fields

fork: Forkblob_schedule: ForkBlobSchedule

Implementations

Source

impl EVMConfig

pub fn new(fork: Fork, blob_schedule: ForkBlobSchedule) -> EVMConfig

pub fn new_from_chain_config( chain_config: &ChainConfig, block_header: &BlockHeader, ) -> Self

pub fn canonical_values(fork: Fork) -> ForkBlobSchedule

This function is used for running the EF tests. If you don’t have acces to a EVMConfig (mainly in the form of a genesis.json file) you can use this function to get the “Default” ForkBlobSchedule for that specific Fork. NOTE: This function could potentially be expanded to include other types of “default“s.