pub enum VMError {
Internal(InternalError),
TxValidation(TxValidationError),
ExceptionalHalt(ExceptionalHalt),
RevertOpcode,
}Variants
Internal(InternalError)
Errors that break execution, they shouldn’t ever happen. Contains subcategory DatabaseError.
TxValidation(TxValidationError)
Returned when a transaction doesn’t pass all validations before executing.
ExceptionalHalt(ExceptionalHalt)
Errors contemplated by the EVM, they revert and consume all gas of the current context.
RevertOpcode
Revert Opcode called. It behaves like ExceptionalHalt, except it doesn’t consume all gas left.
Implementations
Sourceimpl VMError
impl VMError
Sourcepub fn should_propagate(&self) -> bool
pub fn should_propagate(&self) -> bool
These errors are unexpected and indicate critical issues. They should not cause a transaction to revert silently but instead fail loudly, propagating the error.
Sourcepub fn is_revert_opcode(&self) -> bool
pub fn is_revert_opcode(&self) -> bool
Error triggered by revert opcode. This error doesn’t consume all gas left in context.