Module l2_hook

Module l2_hook 

Structs

L2Hook

Constants

COMMON_BRIDGE_L2_ADDRESS
FEE_TOKEN_RATIO_ADDRESS
FEE_TOKEN_REGISTRY_ADDRESS

Functions

deduct_caller_fee_token
Deducts the caller’s balance in the fee token for the upfront gas cost. This is calculated as gas_limit * gas_price. This is done through a call to the fee token contract’s lockFee function.