LevmCallTracer

Struct LevmCallTracer 

pub struct LevmCallTracer {
    pub callframes: Vec<CallTraceFrame>,
    pub only_top_call: bool,
    pub with_log: bool,
    pub active: bool,
}
Geth’s callTracer (https://geth.ethereum.org/docs/developers/evm-tracing/built-in-tracers) Use LevmCallTracer::disabled() when tracing is not wanted.

Fields

callframes: Vec<CallTraceFrame>

Stack for tracer callframes, at the end of execution there will be only one element.

only_top_call: bool

If true, trace only the top call (a.k.a. the external transaction)

with_log: bool

If true, trace logs

active: bool

If active is set to false it won’t trace.

Implementations

Source

impl LevmCallTracer

pub fn new(only_top_call: bool, with_log: bool) -> Self

pub fn disabled() -> Self

This is to keep LEVM’s code clean, like self.tracer.enter(...), instead of something more complex or uglier when we don’t want to trace. (For now that we only implement one tracer it may be the most convenient solution)

pub fn enter( &mut self, call_type: CallType, from: Address, to: Address, value: U256, gas: u64, input: &Bytes, )

Starts trace call.

pub fn exit_context( &mut self, ctx_result: &ContextResult, is_top_call: bool, ) -> Result<(), InternalError>

Exits trace call using the ContextResult.

pub fn exit_early( &mut self, gas_used: u64, error: Option<String>, ) -> Result<(), InternalError>

Exits trace call when CALL or CREATE opcodes return early or in case SELFDESTRUCT is called.

pub fn log(&mut self, log: &Log) -> Result<(), InternalError>

Registers log when opcode log is executed. Note: Logs of callframes that reverted will be removed at end of execution.