pub fn eip7702_get_code(
db: &mut GeneralizedDatabase,
accrued_substate: &mut Substate,
address: Address,
) -> Result<(bool, u64, Address, Code), VMError>Expand description
Gets code of an account, returning early if it’s not a delegated account, otherwise Returns tuple (is_delegated, eip7702_cost, code_address, code). Notice that it also inserts the delegated account to the “accessed accounts” set.
Where:
is_delegated: True if account is a delegated account.eip7702_cost: Cost of accessing the delegated account (if any)code_address: Code address (if delegated, returns the delegated address)code: Bytecode of the code_address, what the EVM will execute.