size_offset_to_usize

Function size_offset_to_usize 

pub fn size_offset_to_usize(
    size: U256,
    offset: U256,
) -> Result<(usize, usize), VMError>
Converts U256 size and offset to usize. If the size is zero, the offset will be zero regardless of its original value as it is not relevant