Structs
- EVMConfig
- This struct holds special configuration variables specific to the
EVM. In most cases, at least at the time of writing (February
2025), you want to use the default blob_schedule values for the
specified Fork. The “intended” way to do this is by using the
EVMConfig::canonical_values(fork: Fork)function. - Environment
- Environmental information that the execution agent must provide.