Module l2_hook
ethrex_
levm
17.0.0
Module l2_hook
Module Items
Structs
Constants
Functions
In ethrex_
levm::
hooks
ethrex_levm
::
hooks
Module
l2_hook
Structs

L2Hook
Constants

COMMON_
BRIDGE_
L2_
ADDRESS
FEE_
TOKEN_
RATIO_
ADDRESS
FEE_
TOKEN_
REGISTRY_
ADDRESS
Functions

deduct_
caller_
fee_
token
Deducts the caller’s balance in the fee token for the upfront gas cost. This is calculated as gas_limit * gas_price. This is done through a call to the fee token contract’s lockFee function.