pub struct LevmCallTracer {
pub callframes: Vec<CallTraceFrame>,
pub only_top_call: bool,
pub with_log: bool,
pub active: bool,
}Expand description
Geth’s callTracer (https://geth.ethereum.org/docs/developers/evm-tracing/built-in-tracers)
Use LevmCallTracer::disabled() when tracing is not wanted.
Fields
callframes: Vec<CallTraceFrame>Stack for tracer callframes, at the end of execution there will be only one element.
only_top_call: boolIf true, trace only the top call (a.k.a. the external transaction)
with_log: boolIf true, trace logs
active: boolIf active is set to false it won’t trace.
Implementations
Sourceimpl LevmCallTracer
impl LevmCallTracer
pub fn new(only_top_call: bool, with_log: bool) -> Self
Sourcepub fn disabled() -> Self
pub fn disabled() -> Self
This is to keep LEVM’s code clean, like self.tracer.enter(...),
instead of something more complex or uglier when we don’t want to trace.
(For now that we only implement one tracer it may be the most convenient solution)
Sourcepub fn enter(
&mut self,
call_type: CallType,
from: Address,
to: Address,
value: U256,
gas: u64,
input: &Bytes,
)
pub fn enter( &mut self, call_type: CallType, from: Address, to: Address, value: U256, gas: u64, input: &Bytes, )
Starts trace call.
Sourcepub fn exit_context(
&mut self,
ctx_result: &ContextResult,
is_top_call: bool,
) -> Result<(), InternalError>
pub fn exit_context( &mut self, ctx_result: &ContextResult, is_top_call: bool, ) -> Result<(), InternalError>
Exits trace call using the ContextResult.
Sourcepub fn exit_early(
&mut self,
gas_used: u64,
error: Option<String>,
) -> Result<(), InternalError>
pub fn exit_early( &mut self, gas_used: u64, error: Option<String>, ) -> Result<(), InternalError>
Exits trace call when CALL or CREATE opcodes return early or in case SELFDESTRUCT is called.